@@ -20,7 +20,7 @@ import os
 import argparse
 import subprocess
 from ete3 import NCBITaxa
-from pkg_resources import get_distribution
+from importlib.metadata import version, PackageNotFoundError
 import time
 
 import fdog.libs.zzz as general_fn
@@ -33,8 +33,8 @@ import fdog.libs.output as output_fn
 
 
 def main():
-    version = get_distribution('fdog').version
-    parser = argparse.ArgumentParser(description='You are running fDOG version ' + str(version) + '.',
+    fdog_version = version("fdog")
+    parser = argparse.ArgumentParser(description='You are running fDOG version ' + str(fdog_version) + '.',
                                      epilog="For more information on certain options, please refer to the wiki pages "
                                             "on github: https://github.com/BIONF/fDOG/wiki")
     required = parser.add_argument_group('Required arguments')
@@ -70,8 +70,9 @@ def main():
                                 action='store_true', default=False)
     core_options.add_argument('--coreHitLimit', help='Number of hits of the initial pHMM based search that should be evaluated via a reverse search. Default: 3',
                                 action='store', default=3, type=int)
-    core_options.add_argument('--distDeviation', help='The deviation in score in percent (0 = 0 percent, 1 = 100 percent) allowed for two taxa to be considered similar. Default: 0.05',
-                                action='store', default=0.05, type=float)
+    core_options.add_argument('--candScoreFactor', help='A multiplier used to set cutoff for candidate selection. A candidate alignment score must exceed the '
+                                'current best score by this factor in order to be considered further. Default: 1.05',
+                                action='store', default=1.05, type=float)
     core_options.add_argument('--alnStrategy', help='Specify the alignment strategy during core ortholog compilation. Default: local',
                                 choices=['local', 'glocal', 'global'],
                                 action='store', default='local')
@@ -93,6 +94,8 @@ def main():
                                 action='store', default=0.0001, type=float)
     ortho_options.add_argument('--hitLimit', help='number of hits of the initial pHMM based search that should be evaluated via a reverse search. Default: 10',
                                 action='store', default=10, type=int)
+    ortho_options.add_argument('--hmmScoreType', help='Choose type of hmm score (best domain or full sequence score) for validating HMM candidates (NOTE: applied also for the core compilation). Default: domain',
+                                action='store', choices=['domain','sequence'], default='domain')
     ortho_options.add_argument('--scoreCutoff', help='Define the percent range of the hmms core of the best hit up to which a candidate of the hmmsearch will be subjected for further evaluation. Default: 10',
                                 action='store', default=10, type=int)
 
@@ -101,6 +104,7 @@ def main():
                                 help='Specifiy mode for filtering core orthologs by FAS score. In \'relaxed\' mode candidates with insufficient FAS score will be disadvantaged. In \'strict\' mode candidates with insufficient FAS score will be deleted from the candidates list. The option \'--minScore\' specifies the cut-off of the FAS score.',
                                 choices=['relaxed', 'strict'], action='store', default='')
     fas_options.add_argument('--minScore', help='Specify the threshold for coreFilter. Default: 0.75', action='store', default=0.75, type=float)
+    fas_options.add_argument('--featureFile', help='File that contains tools used for FAS calculation', action='store', default='')
 
     addtionalIO = parser.add_argument_group('Other I/O options')
     addtionalIO.add_argument('--append', help='Append the output to existing output files', action='store_true', default=False)
@@ -147,7 +151,7 @@ def main():
     CorecheckCoorthologsOff = args.CorecheckCoorthologsOff
     coreRep = args.coreRep
     coreHitLimit = args.coreHitLimit
-    distDeviation = args.distDeviation
+    distDeviation = max(round(args.candScoreFactor - 1, 2), 0) #args.distDeviation
     alnStrategy = args.alnStrategy
 
     # ortholog search arguments
@@ -166,12 +170,14 @@ def main():
     evalBlast = args.evalBlast
     evalHmmer = args.evalHmmer
     hitLimit = args.hitLimit
+    hmmScoreType = args.hmmScoreType
     scoreCutoff = args.scoreCutoff
 
     # fas arguments
     fasOff = args.fasOff
     coreFilter = args.coreFilter
     minScore = args.minScore
+    featureFile = args.featureFile
 
     # other I/O arguments
     append = args.append
@@ -222,6 +228,8 @@ def main():
         check_fas = fas_fn.check_fas_executable()
         if check_fas == 0:
             sys.exit('ERROR: FAS is not executable! You still can use fDOG with --fasOff!')
+    check_time = time.time()
+    print('==> Preparation finished in ' + '{:5.3f}s'.format(check_time - begin))
 
     ##### Identify seed ID from refspec genome
     if reuseCore:
@@ -236,7 +244,7 @@ def main():
     coreArgs = [minDist, maxDist, coreSize, coreTaxa, distDeviation,
                 alnStrategy, fasOff]
     orthoCoreArgs = [CorecheckCoorthologsOff, rbh, True, evalBlast/10,
-                    lowComplexityFilter, evalHmmer/10, coreHitLimit,
+                    lowComplexityFilter, evalHmmer/10, coreHitLimit, hmmScoreType,
                     scoreCutoff, aligner] # rep = True; e-value cutoff is 10x more stringent than from ortho search
     otherCoreArgs = [cpus, debugCore, silentOff, noCleanup, force, append]
     print('##### COMPILING CORE SET FOR %s #####' % seqName)
@@ -262,7 +270,7 @@ def main():
                 exit('ERROR: Taxon group "%s" invalid!' % group)
             ### create taxonomy tree from list of search taxa
             searchTaxa = []
-            tax_ids = core_fn.get_core_taxa_ids(coreTaxa, corepath)
+            tax_ids = ortho_fn.get_search_taxa_ids(searchTaxa, searchpath)
 
             for tax_id in tax_ids.keys():
                 check = tree_fn.check_taxon_group(group_id[group][0], tax_id, ncbi)
@@ -275,7 +283,7 @@ def main():
                 searchTaxa = ','.join(searchTaxa)
         # do ortholog search
         orthoArgs = [checkCoorthologsRefOff, rbh, rep, evalBlast,
-                    lowComplexityFilter, evalHmmer, hitLimit, scoreCutoff, aligner]
+                    lowComplexityFilter, evalHmmer, hitLimit, hmmScoreType, scoreCutoff, aligner]
         otherArgs = [searchTaxa, cpus, debug, silentOff, noCleanup, force, append]
         hamstr_out = ortho_fn.run_hamstr([seqName, refspec, pathArgs, orthoArgs, otherArgs])
         output_fn.write_hamstr(hamstr_out, outpath, seqName, force, append)
@@ -291,7 +299,7 @@ def main():
                 sys.exit('Problem with FAS! Please check https://github.com/BIONF/FAS or turn it off if not needed!')
             if os.path.exists(finalOutfile):
                 start = time.time()
-                fas_fn.calc_fas_multi(finalOutfile, outpath, annopath, cpus)
+                fas_fn.calc_fas_multi(finalOutfile, outpath, annopath, cpus, featureFile)
                 end = time.time()
                 print('==> FAS calculation finished in ' + '{:5.3f}s'.format(end - start))
         else:
