@@ -24,7 +24,7 @@ import subprocess
 import shutil
 from ete3 import NCBITaxa
 from pathlib import Path
-from pkg_resources import get_distribution
+from importlib.metadata import version, PackageNotFoundError
 
 import fdog.libs.zzz as general_fn
 import fdog.libs.fas as fas_fn
@@ -157,7 +157,15 @@ def download_data(dataPath, resetData):
         data_url = 'https://applbio.biologie.uni-frankfurt.de/download/hamstr_qfo'
         if os.path.exists(data_fdog_file) and resetData:
             os.remove(data_fdog_file)
-        general_fn.download_file(data_url, data_fdog_file)
+        # general_fn.download_file(data_url, data_fdog_file)
+        ####### temporary solution while the uni network does not work #########
+        wgetCmd = 'wget "https://www.dropbox.com/scl/fi/t2ln18k0jthc3y74s591q/data_HaMStR-2019c.tar.gz?rlkey=c66nc3eslqyn2a6k6ey4e678r&st=plzvbllv&dl=0"'
+        try:
+            subprocess.run([wgetCmd], shell=True, check=True)
+            shutil.move("data_HaMStR-2019c.tar.gz?rlkey=c66nc3eslqyn2a6k6ey4e678r&st=plzvbllv&dl=0", "data_HaMStR-2019c.tar.gz")
+        except:
+            print('Problem occurred while download demo data from dropbox')
+        ########################################################################
         try:
             print('Extracting %s...' % data_fdog_file)
             shutil.unpack_archive(data_fdog_file, dataPath, 'gztar')
@@ -193,8 +201,8 @@ def write_pathconfig(fdogPath, dataPath):
 
 
 def main():
-    version = get_distribution('fdog').version
-    parser = argparse.ArgumentParser(description='You are running fDOG version ' + str(version) + '.')
+    fdog_version = version("fdog")
+    parser = argparse.ArgumentParser(description='You are running fDOG version ' + str(fdog_version) + '.')
     required = parser.add_argument_group('required arguments')
     optional = parser.add_argument_group('optional arguments')
     required.add_argument('-d', '--dataPath', help='Output path for fDOG data', action='store', default='', required=True)
@@ -254,11 +262,37 @@ def main():
         if check_conda_env() == True:
             req_file = '%s/data/conda_requirements.yml' % fdogPath
             print('=> Dependencies in %s' % req_file)
-            conda_install_cmd = 'conda install -c bioconda --file %s -y' % (req_file)
+
+            install_cmd = f'install -c bioconda --file {req_file} -y'
+            if shutil.which("micromamba"):
+                install_cmd = f'micromamba {install_cmd}'
+            elif shutil.which("mamba"):
+                install_cmd = f'mamba {install_cmd}'
+            else:
+                install_cmd = f'conda {install_cmd}'
             try:
-                subprocess.call([conda_install_cmd], shell = True)
+                subprocess.call(install_cmd, shell=True)
             except:
-                sys.exit('\033[91mERROR: Cannot install conda packages in %s!\033[0m' % req_file)
+                sys.exit(f'\033[91mERROR: Cannot install conda packages in {req_file}!\033[0m')
+
+
+            # micromamba_install_cmd = 'micromamba install -c bioconda --file %s -y' % (req_file)
+            # mamba_install_cmd = 'mamba install -c bioconda --file %s -y' % (req_file)
+            # conda_install_cmd = 'conda install -c bioconda --file %s -y' % (req_file)
+            # try:
+            #     # Try to use micromamba first
+            #     subprocess.check_call(micromamba_install_cmd, shell=True)
+            # except subprocess.CalledProcessError as e:
+            #     try:
+            #         # If micromamba fails, try mamba
+            #         subprocess.check_call(mamba_install_cmd, shell=True)
+            #     except subprocess.CalledProcessError as e:
+            #         try:
+            #             # If both fail, try conda
+            #             subprocess.check_call(conda_install_cmd, shell=True)
+            #         except subprocess.CalledProcessError as e:
+            #             # If all installation attempts fail, exit with an error message
+            #             sys.exit('\033[91mERROR: Cannot install conda packages in %s!\033[0m' % req_file)
         else:
             install_cmd = 'sudo apt-get install -y -qq <tool>'
             sys.exit('\033[91mERROR: Please install these tools manually:\n%s\nusing the command: %s!\033[0m' % (', '.join(missing_tools), install_cmd))
